fixed name;
authorwenzelm
Fri, 15 Sep 2000 11:27:45 +0200
changeset 9967 179dad40babc
parent 9966 e2ddb6a12427
child 9968 264b16d934f9
fixed name;
lib/scripts/fixsome.pl
--- a/lib/scripts/fixsome.pl	Fri Sep 15 11:17:33 2000 +0200
+++ b/lib/scripts/fixsome.pl	Fri Sep 15 11:27:45 2000 +0200
@@ -3,10 +3,10 @@
 # Author: Markus Wenzel, TU Muenchen
 # License: GPL (GNU GENERAL PUBLIC LICENSE)
 #
 # fixclasimp.pl - fix references to implicit claset and simpset
 #
 
-sub fixclasimp {
+sub fixsome {
     my ($file) = @_;
 
     open (FILE, $file) || die $!;
@@ -40,6 +40,6 @@
 ## main
 
 foreach $file (@ARGV) {
-  eval { &fixclasimp($file); };
-  if ($@) { print STDERR "*** fixclasimp $file: ", $@, "\n"; }
+  eval { &fixsome($file); };
+  if ($@) { print STDERR "*** fixsome $file: ", $@, "\n"; }
 }
@@ -3,10 +3,10 @@
 # License: GPL (GNU GENERAL PUBLIC LICENSE)
 #
-# fixclasimp.pl - fix references to implicit claset and simpset
+# fixsome.pl - fix references to implicit claset and simpset
 #
 